{% if heading %}
    <h5>{{ heading }}</h5>
{% endif %}

<table class="{% if class %}{{ class }}{% else %}data-table{% endif %}" cellpadding="2" cellspacing="2">
    {{ text|safe }}
</table>
<span class="clear"></span>
