{% load static %}

<table cellpadding="0" cellspacing="0" class="orange-headline">
    <tr>
        {% if image %}
            <td class="orange-icon">
                <img src="cid:{% static image %}" alt="{{ text }}" width="38" class="product-icon-img">
            </td>
        {% endif %}
        <td class="orange-spacer" width="15"> </td>
        <td class="orange-name">
            {% if heading %}
                <b class="lead">{{ heading }}</b>
            {% endif %}
            {% if heading and text %}
                <br>
            {% endif %}
            {% if text %}
                {{ text|safe }}
            {% endif %}
        </td>
    </tr>
</table>
