{% load static email_components %}

<table cellpadding="0" cellspacing="0" class="warning-headline">
    <tr>
        <td class="warning-icon">
            <img src="cid:{% static "img/email/som/warning.png" %}" alt="Warnung" width="17" height="15">
        </td>
        <td class="warning-name">
            {{ text }}
        </td>
    </tr>
</table>
