{% extends 'email/som/empty.html' %}
{% load email_components %}

{% block emailbody %}
    {% emailheader %}{% endemailheader %}
    {% block content %}{% endblock %}
    {% emailfooter %}{% endemailfooter %}
    {% block unsubscribe %}
        {% emailunsubscribe %}{% endemailunsubscribe %}
    {% endblock %}
{% endblock %}
