{% load static email_components %}

<table cellpadding="0" cellspacing="0" class="product-headline">
    <tr>
        <td>
            {% if center %}
                {% emailcenter %}{% emailsectionheadline %}{{ text|safe }}{% endemailsectionheadline %}{% endemailcenter %}
            {% else %}
                {% emailsectionheadline %}{{ text|safe }}{% endemailsectionheadline %}
            {% endif %}
        </td>
    </tr>
</table>
{% emailspacer %}{% endemailspacer %}
