{% load email_components %}

{% if text or email_unsubscribe %}
    {% emaillinebreak %}{% endemaillinebreak %}
    <div style="padding: 0 20px;">
        {% emailparagraph %}
            {% emailcolor color="#878787" %}
                {% emailsmall %}
                    {% if text %}
                        {{ text|safe }}
                    {% endif %}
                    {% if email_unsubscribe %}
                        {{ email_unsubscribe.text }}
                        {% emaillink placeholder=email_unsubscribe.url_name %}{{ email_unsubscribe.url }}{% endemaillink %}
                    {% endif %}
                {% endemailsmall %}
            {% endemailcolor %}
        {% endemailparagraph %}
    </div>
{% endif %}
