<table class="button large {% if secondary %}secondary{% endif %}"{% if center %} style="margin: auto;"{% endif %}>
    <tbody>
        <tr>
            <td>
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <a href="{{ link }}" target="_blank">{{ text }}</a>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </td>
        </tr>
    </tbody>
</table>
