{% if heading %}
    <h5>{{ heading }}</h5>
{% endif %}

<table class="{% if class %}{{ class }}{% endif %}" cellpadding="0" cellspacing="0" style="{% if style %}{{ style }}{% endif %}">
    {{ text|safe }}
</table>
