{% load email_components %}

{% emailspacer %}{% endemailspacer %}
<table cellspacing="0" cellpadding="0" style="padding: 0 30px">
    <tr>
        <td>
            {% if text %}
                {% emailparagraph %}
                    {{ text|safe }}
                {% endemailparagraph %}
            {% endif %}
            {% emailparagraph %}
                Beste Grüße
                {% emaillinebreak %}{% endemaillinebreak %}
                {% if service_contacts and service_contacts.name %}
                    {{ service_contacts.name }}
                {% elif name %}
                    {{ name }}
                {% else %}
                    Ihr Kundenservice-Team
                {% endif %}
            {% endemailparagraph %}
        </td>
    </tr>
</table>
