{% for s in '12345' %}
    {% if s <= score|stringformat:'d' %}
        <span style="font-size: 20px; color: orange">&#9733;</span>
    {% else %}
        <span style="font-size: 20px; color: orange; text-shadow: -0.5px 0 orange, 0 1px orange, 0.5px 0 orange, 0 -0.5px orange">&#9734;</span>
    {% endif %}
{% endfor %}
