{% load email_components %}

{% if ca_notification_settings_link %}
    {% emailspacer %}{% endemailspacer %}
    {% emailsmall %}
        Sie möchten diese Benachrichtigung nicht mehr erhalten?
        {% emaillink placeholder="Benachrichtigungen hier deaktivieren" %}{{ ca_notification_settings_link }}{% endemaillink %}
    {% endemailsmall %}
{% endif %}

{% emailspacer %}{% endemailspacer %}
<table class="social" width="100%" cellspacing="0" cellpadding="0">
    <tbody>
        <tr>
            <td>
                <table align="left" class="column first" width="138">
                    <tbody>
                        <tr>
                            <td width="138">
                                <p class="last">
                                    <b>RegioHelden GmbH</b>
                                    <br>
                                    Rotebühlstraße 50
                                    <br>
                                    70178 Stuttgart
                                </p>
                            </td>
                        </tr>
                    </tbody>
                </table>

                <table align="left" class="column register" width="138">
                    <tbody>
                        <tr>
                            <td width="138">
                                <p class="last">
                                    <b>Registergericht:</b>
                                    <br>
                                    Amtsgericht Stuttgart
                                    <br>
                                    HRB 733189
                                </p>
                            </td>
                        </tr>
                    </tbody>
                </table>

                <table align="left" class="column ceo" width="160">
                    <tbody>
                        <tr>
                            <td width="160">
                                <p class="last">
                                    <b>Geschäftsführer:</b>
                                    <br>
                                    Dr. Andreas Müller-Leydig, Christoph Kreuzer
                                </p>
                            </td>
                        </tr>
                    </tbody>
                </table>

                <table align="left" class="column last" width="106">
                    <tbody>
                        <tr>
                            <td width="106">
                                <p class="last"><a href="https://stroeer-online-marketing.de">www.stroeer-om.de</a><br>
                                <a href="https://stroeer-online-marketing.de/downloads/">AGB</a><br></p>
                            </td>
                        </tr>
                    </tbody>
                </table>

                <span class="clear"></span>
            </td>
        </tr>
    </tbody>
</table>

{% emailspacer %}{% endemailspacer %}
