{% load static %}

<table class="head-wrap">
	<tr>
		<td></td>
		<td class="header container">
			<div class="content">
				<table class="no-spacing">
					<tr>
						<td>
							<table bgcolor="#FFFFFF" cellspacing="30" class="head-inner" width="600">
								<tr>
									<td class="logo">
										<img src="cid:{% static "img/email/som/logo_som.png" %}" alt="Ströer Online Marketing" class="logo-img logo-som" width="290" />
									</td>
									<td align="right" class="desktop-only logo">
										<img src="cid:{% static "img/email/som/logo_regiohelden_omnea.png" %}" alt="RegioHelden / Omnea" class="logo-img logo-rh" width="191" />
									</td>
								</tr>
							</table>
						</td>
					</tr>
				</table>
			</div>
		</td>
		<td></td>
	</tr>
</table>
