{% load static %}
{% load phone_format %}
{% load email_components %}

{% emailspacer %}{% endemailspacer %}
<table cellpadding="0" cellspacing="0" class="callout-box">
    <tr>
        <td class="callout-icon">
            <img
                {% if not service_contacts.badge %}
                    src="cid:{% static "img/email/som/cta.png" %}"
                {% else %}
                    src="cid:{{ service_contacts.badge.url }}"
                {% endif %}
                alt="{{ service_contacts.name }}"
                height="83" width="83" class="product-icon-img" />
        </td>
        <td class="callout-name">
            <b class="lead">{{ service_contacts.name }}</b>
            <br>
            {{ service_contacts.email }}
            <br>
            {{ service_contacts.phone|separate_by_slash }}
        </td>
    </tr>
</table>
